Struct key_rwlock::KeyRwLock

source ·
pub struct KeyRwLock<K> { /* private fields */ }
An async reader-writer lock, that locks based on a key, while allowing other keys to lock independently. Based on a HashMap of RwLocks.

Implementations

source

impl<K> KeyRwLock<K>where K: Eq + Hash + Send + Clone,

source

pub fn new() -> Self

Create new instance of a KeyRwLock

source

pub async fn read(&self, key: K) -> OwnedRwLockReadGuard<()>

Lock this key with shared read access, returning a guard. Cleans up locks every 1000 accesses.

source

pub async fn write(&self, key: K) -> OwnedRwLockWriteGuard<()>

Lock this key with exclusive write access, returning a guard. Cleans up locks every 1000 accesses.

source

pub async fn try_read( &self, key: K ) -> Result<OwnedRwLockReadGuard<()>, TryLockError>

Try lock this key with shared read access, returning immediately. Cleans up locks every 1000 accesses.

source

pub async fn try_write( &self, key: K ) -> Result<OwnedRwLockWriteGuard<()>, TryLockError>

Try lock this key with exclusive write access, returning immediately. Cleans up locks every 1000 accesses.

source

pub async fn clean(&self)

Clean up by removing locks that are not locked.